"use strict";

var _resolve = _interopRequireDefault(require("../resolve"));

var _compileRoutes = _interopRequireDefault(require("../compileRoutes"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('resolve', function () {
  it('should return null when routes are empty', function () {
    expect((0, _resolve.default)([], '/foo/')).toEqual(null);
  });
  it("should return null when there isn't a match", function () {
    var routes = (0, _compileRoutes.default)([{
      path: '/bar/',
      name: 'bar',
      page: 'Bar'
    }, {
      path: '/baz/',
      name: 'baz',
      page: 'Baz'
    }]);
    expect((0, _resolve.default)(routes, '/foo/')).toEqual(null);
  });
  it('should return params for simple matches', function () {
    var routes = (0, _compileRoutes.default)([{
      path: '/bar/',
      name: 'bar',
      page: 'Bar'
    }, {
      path: '/foo/',
      name: 'foo',
      page: 'Foo'
    }]);
    expect((0, _resolve.default)(routes, '/foo/')).toEqual({
      page: '/Foo',
      query: {}
    });
  });
  it('returned params should include any explicit params', function () {
    var routes = (0, _compileRoutes.default)([{
      path: '/foo/',
      name: 'foo',
      page: 'Foo',
      params: {
        country: 'gb',
        language: 'en'
      }
    }]);
    expect((0, _resolve.default)(routes, '/foo/')).toEqual({
      page: '/Foo',
      query: {
        country: 'gb',
        language: 'en'
      }
    });
  });
  it('should match parameterised segments', function () {
    var routes = (0, _compileRoutes.default)([{
      path: '/:slug/',
      name: 'foo',
      page: 'Foo',
      params: {
        country: 'gb',
        language: 'en'
      }
    }]);
    expect((0, _resolve.default)(routes, '/foo/')).toEqual({
      page: '/Foo',
      query: {
        country: 'gb',
        language: 'en',
        slug: 'foo'
      }
    });
  });
  it('routes defined first take precedence', function () {
    var routes = (0, _compileRoutes.default)([{
      path: '/foo/',
      name: 'foo',
      page: 'Foo'
    }, {
      path: '/:slug/',
      name: 'bar',
      page: 'Bar'
    }]);
    expect((0, _resolve.default)(routes, '/foo/')).toEqual({
      page: '/Foo',
      query: {}
    });
  });
  it('query strings are added to return query', function () {
    var routes = (0, _compileRoutes.default)([{
      path: '/:slug/',
      name: 'foo',
      page: 'Foo'
    }]);
    expect((0, _resolve.default)(routes, '/foo/?bar=baz')).toEqual({
      page: '/Foo',
      query: {
        slug: 'foo',
        bar: 'baz'
      }
    });
  });
  it('repeated query strings are turned to arrays', function () {
    var routes = (0, _compileRoutes.default)([{
      path: '/foo/',
      name: 'foo',
      page: 'Foo'
    }]);
    expect((0, _resolve.default)(routes, '/foo/?bar=baz&bar=buzz')).toEqual({
      page: '/Foo',
      query: {
        bar: ['baz', 'buzz']
      }
    });
  });
});